/**************************************************************************/
/*                                                                        */
/*   ________                                                             */
/*   ()_______)                                                           */
/*    \:::::::\        Make your mark on open source, let people know     */
/*     \:::::::\       what you can do, profit on reputation.             */
/*     @:::::::/                                                          */
/*      ~~~~~~~                                                           */
/* ---------------------------------------------------------------------- */
/*  Scott Auge sauge@amduus.com scott_auge@yahoo.com                      */
/*  Amduus Information Works, Inc.                                        */
/*  http://www.amduus.com                                                 */
/*                                                                        */
/*  Initial development                                                   */
/*                                                                        */
/* ---------------------------------------------------------------------- */
/*                                                                        */
/**************************************************************************/



/**************************************************************************/
/*                                                                        */ 
/*           .-.------------------------------------------.-.             */
/*          ((o))                                            )            */
/*           \U/_______          _____         ______   ____/             */
/*             |                                           |              */
/*             |         #####    #####  ######            |              */
/*             |         #     # #     # #     #           |              */
/*             |         #     # #       #     #           |              */
/*             |         ######   #####  #     #           |              */
/*             |         #     #       # #     #           |              */
/*             |         #     # #     # #     #           |              */
/*             |         ######   #####  ######            |              */
/*             |                                           |              */
/*             |                                           |              */
/*             |                                           |              */
/*             |____    _______    __  ____    _   ___   __|KCK/SGA       */
/*            /A\                                           \             */
/*           ((o))                                           )            */
/*            '-'-------------------------------------------              */
/*                                                                        */
/*                                                                        */
/* Copyright 2018, Amduus Information Works, Inc., Scott Auge             */
/* sauge@amduus.com scott_auge@yahoo.com scottauge@gmail.com              */
/* https://www.linkedin.com/in/scottauge/                                 */
/* All rights reserved.                                                   */
/*                                                                        */
/* Redistribution and use in source and binary forms, with or without     */
/* modification, are permitted provided that the following conditions are */
/* met:                                                                   */
/*                                                                        */
/*   - Redistributions of source code must retain the above copyright     */
/*     notice, this list of conditions and the following disclaimer.      */
/*   - Redistributions in binary form must reproduce the above copyright  */
/*     notice, this list of conditions and the following disclaimer in    */
/*     the documentation and/or other materials provided with the         */
/*     distribution.                                                      */
/*   - Neither the name of the Amduus Information Works, Inc. nor the     */
/*     names of its contributors may be used to endorse or promote        */
/*     products derived from this software without specific prior written */
/*     permission.                                                        */
/*                                                                        */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS    */
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT      */
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR  */
/* A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT   */
/* HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, */
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT       */
/* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,  */
/* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY  */
/* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT    */
/* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE  */
/* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.   */
/*                                                                        */ 
/**************************************************************************/ 

/* Used for debugging */

&scoped-define log if false then message



define variable BaseDirectory as character no-undo.
define variable DevelopmentDirectory as character format "x(50)" no-undo.
define variable ProjectNumber as character format "x(50)" no-undo.
define variable ProjectDirectory as character no-undo.


/**************************************************************************/ 
/* Here is were you tailor the program to your environment.               */
/**************************************************************************/ 

&scoped-define OpeningProgram nothing.p
DevelopmentDirectory ="/appl/saas".




/**************************************************************************/ 
/* Do not edit past here without an idea of what you are doing!           */
/**************************************************************************/


form
"Development Directory:" DevelopmentDirectory no-label skip
"       Project Number:" ProjectNumber no-label
with frame Sessions
     title "Session Aspects".


/* Go out and insure our directories are available */

run BuildBaseDirectory (output BaseDirectory).



/* What project are we working on */

update 
DevelopmentDirectory
ProjectNumber
with frame Sessions centered row 5.



/* Add project number to our BaseDirectory $HOME/projects/projnumber */

ProjectDirectory = BaseDirectory + "/" + ProjectNumber.
run MakeDirectory (ProjectDirectory).

propath = ProjectDirectory + ":" + propath.


/*****************************************************************************/
/* The idea here is that this session will use the project directory, then   */
/* the development environment to find code to execute.                      */
/* Leaving the program will put you in the double bars.                      */
/*****************************************************************************/

run {&OpeningProgram}.

/* quit. */




/*****************************************************************************/
/* We are currectly allowed on home directory in the propath.  Copy the di-  */
/* rectory structure into this project directory.  Structure means no source */
/* files - only the subdirectories of the DevelopmentDirectory.              */
/*****************************************************************************/
 
procedure CopySourceDirectoryStructure:

  define variable TempFile as character no-undo.
  define variable OSCommand as character no-undo.
  define variable DirectoryLine as character no-undo.


  /* Create a temp file and use UNIX find to create a directory structure */

  TempFile = BaseDirectory
           + "/_" 
           + string(time).

  OSCommand = "cd " 
            + DevelopmentDirectory
            + "; find . -type d > "
            + TempFile.

  {&log} OSCommand.


  os-command value(OSCommand).



  /* Go through that file and make that directory in the project directory */

  input from value (TempFile).

  repeat on end-key undo, leave:
 
    import unformatted DirectoryLine.

    DirectoryLine = replace (DirectoryLine, "./", "").

    DirectoryLine = ProjectDirectory
                  + "/"
                  + DirectoryLine.

    os-create-dir value(DirectoryLine).

  end. /* repeat */

  input close.


  /* Clean up that file */

  os-delete value(TempFile).



end.  /* CopySourceDirectoryStructure */



/*****************************************************************************/
/* This will assume your projects controlled by this software will be in     */
/* your UNIX $HOME directory + projects.                                     */
/*****************************************************************************/

procedure BuildBaseDirectory:

  define output parameter BaseDirectory as character no-undo.

  BaseDirectory = os-getenv("HOME") + "/projects".

  run MakeDirectory (BaseDirectory).

end. /* BuildBaseDirectory */



/*****************************************************************************/
/* This will create the directory if it does not exist.  If it does exist,   */
/* it will do nothing.                                                       */
/*****************************************************************************/

procedure MakeDirectory:

  define input parameter Directory as character no-undo.

  file-info:file-name = Directory.

  /* If making a new directory, copy the directory structure of the development */
  /* environment into the new directory */

  if file-info:full-pathname = ? then do:
    os-create-dir value(Directory).
    run CopySourceDirectoryStructure.
  end.

end. /* MakeDirectory */

